@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.7
-;; Package-Requires: ((emacs "28.1") (compat "30"))
+;; Version: 1.8
+;; Package-Requires: ((emacs "28.1") (org "9.5") (compat "30"))
 ;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
 
@@ -29,7 +29,7 @@
 
 ;; This package adds some styling to your Org buffer, which gives it a
 ;; modern look.  Enable the styling by default with:
-;;   (add-hook 'org-mode-hook 'org-modern-mode)
+;;   (global-org-modern-mode)
 
 ;;; Code:
 
@@ -75,8 +75,9 @@ tree is folded or expanded."
 
 (defcustom org-modern-hide-stars 'leading
   "Changes the displays of the stars.
-Can be leading, t, or a string/character replacement for each
-leading star.  Set to nil to disable."
+Can be leading, t, or a string/character replacement for each leading
+star.  Set to nil to disable.  This feature is automatically disabled if
+`org-indent-mode' is enabled."
   :type '(choice
           (string :tag "Replacement string for leading stars")
           (character :tag "Replacement character for leading stars")
@@ -220,9 +221,10 @@ all other blocks."
 
 (defcustom org-modern-block-fringe 2
   "Add a border to the blocks in the fringe.
-This variable can also be set to an integer between 0 and 16,
-which specifies the offset of the block border from the edge of
-the window."
+This variable can also be set to an integer between 0 and 16, which
+specifies the offset of the block border from the edge of the
+window.  This feature is automatically disabled if `org-indent-mode' is
+enabled."
   :type '(choice boolean natnum))
 
 (defcustom org-modern-keyword t
@@ -284,6 +286,9 @@ on their font, e.g., the :width or :height parameters.  Themes
 should not override this face, since themes usually don't control
 the font.")
 
+(defface org-modern-habit nil
+  "Parent face for habits.")
+
 (defface org-modern-block-name
   '((t :height 0.8 :weight light))
   "Face used for block keywords.")
@@ -528,17 +533,19 @@ the font.")
   "Prettify headline stars."
   (let* ((beg (match-beginning 1))
          (end (match-end 1))
-         (level (- end beg)))
+         (level (- end beg))
+         (hide-leading (and (eq org-modern-hide-stars 'leading)
+                            (not (bound-and-true-p org-indent-mode)))))
     (when (and org-modern--hide-stars-cache (not (eq beg end)))
       (cl-loop for i from beg below end do
                (put-text-property i (1+ i) 'display
                                   (nth (logand i 1)
                                        org-modern--hide-stars-cache))))
     (when org-modern-star
-      (when (and (eq org-modern-hide-stars 'leading) org-hide-leading-stars)
+      (when (and hide-leading org-hide-leading-stars)
         (put-text-property beg (1+ end) 'face (get-text-property end 'face)))
       (put-text-property
-       (if (eq org-modern-hide-stars 'leading) beg end)
+       (if hide-leading beg end)
        (1+ end) 'display
        (let ((cache (if (and org-modern--folded-star-cache
                              (org-invisible-p (pos-eol)))
@@ -659,7 +666,7 @@ whole buffer; otherwise, for the line at point."
                        (face-attribute 'org-modern-label :box nil t))))
     (unless (equal (and (listp box) (plist-get box :color))
                    (face-attribute 'default :background nil t))
-      (org-modern--update-label-face)))
+      (org-modern--update-faces)))
   (let ((face-remapping-alist
          `((default org-table
             ,@(or (ensure-list (cdr (assq 'default face-remapping-alist)))
@@ -668,24 +675,22 @@ whole buffer; otherwise, for the line at point."
     (setq org-modern--table-sp-width (default-font-width)))
   (setf (cadr org-modern--table-overline) (face-attribute 'org-table :foreground nil t)))
 
-(defun org-modern--update-label-face ()
+(defun org-modern--update-faces ()
   "Update border of the `org-modern-label' face."
-  (set-face-attribute
-   'org-modern-label nil
-   :box
-   (when org-modern-label-border
-     (let ((border (if (integerp org-modern-label-border)
-                       org-modern-label-border
-                     (max 2 (cond
-                             ((integerp line-spacing)
-                              line-spacing)
-                             ((floatp line-spacing)
-                              (ceiling (* line-spacing (frame-char-height))))
-                             (t (/ (frame-char-height) 10)))))))
-       (list :color (face-attribute 'default :background nil t)
-             :line-width (cons -1 (- border)))))))
+  (let* ((border (if (integerp org-modern-label-border)
+                     org-modern-label-border
+                   (max 2 (cond
+                           ((integerp line-spacing)
+                            line-spacing)
+                           ((floatp line-spacing)
+                            (ceiling (* line-spacing (frame-char-height))))
+                           (t (/ (frame-char-height) 10))))))
+         (box (list :color (face-attribute 'default :background nil t)
+                    :line-width (cons -1 (- border)))))
+    (set-face-attribute 'org-modern-label nil :box box)
+    (set-face-attribute 'org-modern-habit nil :box box)))
 
-(defun org-modern--update-fringe-bitmaps ()
+(defun org-modern--update-bitmaps ()
   "Update fringe bitmaps."
   (when (and org-modern-block-fringe
              (fboundp 'fringe-bitmap-p)
@@ -726,9 +731,11 @@ whole buffer; otherwise, for the line at point."
    (when org-modern-checkbox
      `((,org-list-full-item-re
         (3 (org-modern--checkbox) nil t))))
-   (when (or org-modern-star org-modern-hide-stars)
+   (when (or org-modern-star (and org-modern-hide-stars
+                                  (not (bound-and-true-p org-indent-mode))))
      `(("^\\(\\**\\)\\* "
-        (0 ,(if (eq org-modern-hide-stars t)
+        (0 ,(if (and (eq org-modern-hide-stars t)
+                     (not (bound-and-true-p org-indent-mode)))
                 ''(face nil invisible org-modern)
               '(org-modern--star))))))
    (when org-modern-horizontal-rule
@@ -818,7 +825,7 @@ whole buffer; otherwise, for the line at point."
           ,@(car specs))
          ("^\\([ \t]*\\)\\(#\\+\\(?:end\\|END\\)_\\)\\(\\S-+\\).*"
           ,@(cdr specs)))))
-   (when (fboundp 'org-activate-folds)
+   (when (fboundp 'org-activate-folds) ;; Since Org 9.7.25
      '(org-activate-folds))))
 
 ;;;###autoload
@@ -841,7 +848,8 @@ whole buffer; otherwise, for the line at point."
                                                     (mapcar #'cdr org-modern-fold-stars)
                                                   org-modern-replace-stars))))
      org-modern--hide-stars-cache
-     (and (char-or-string-p org-modern-hide-stars)
+     (and (and (char-or-string-p org-modern-hide-stars)
+               (not (bound-and-true-p org-indent-mode)))
           (list (org-modern--symbol org-modern-hide-stars)
                 (org-modern--symbol org-modern-hide-stars)))
      org-modern--checkbox-cache
@@ -860,8 +868,8 @@ whole buffer; otherwise, for the line at point."
     (add-hook 'org-after-demote-entry-hook #'org-modern--unfontify-line nil 'local)
     (when (eq org-modern-star 'fold)
       (add-hook 'org-cycle-hook #'org-modern--cycle nil 'local))
-    (org-modern--update-label-face)
-    (org-modern--update-fringe-bitmaps))
+    (org-modern--update-faces)
+    (org-modern--update-bitmaps))
    (t
     (remove-from-invisibility-spec 'org-modern)
     (font-lock-remove-keywords nil org-modern--font-lock-keywords)
@@ -898,6 +906,12 @@ whole buffer; otherwise, for the line at point."
   (remove-from-invisibility-spec 'org-modern)
   (add-to-invisibility-spec 'org-modern) ;; Not idempotent?!
   (add-hook 'pre-redisplay-functions #'org-modern--pre-redisplay nil 'local)
+  (setq-local face-remapping-alist (copy-tree face-remapping-alist))
+  (maphash (lambda (face _spec)
+             (when (string-prefix-p "org-habit-" (symbol-name face))
+               (setf (alist-get face face-remapping-alist nil 'remove)
+                     (and org-modern-label-border `(org-modern-habit ,face)))))
+           face--new-frame-defaults)
   (save-excursion
     (save-match-data
       (let (case-fold-search)
